summaryrefslogtreecommitdiff
path: root/Porting/add-package.pl
diff options
context:
space:
mode:
authorDavid Steinbrunner <dsteinbrunner@pobox.com>2013-05-21 06:56:08 -0400
committerRicardo Signes <rjbs@cpan.org>2013-05-24 10:18:31 -0400
commit730ad6b92c67f5477893aa2deaa6c6832860a024 (patch)
treebac6f8fbdc6bd3a66b817f037a6daa0d745e80f4 /Porting/add-package.pl
parent8524aa6e56ea4ae1610e36bc239b06bfb087e84b (diff)
downloadperl-730ad6b92c67f5477893aa2deaa6c6832860a024.tar.gz
typo fixes for porting scripts
Diffstat (limited to 'Porting/add-package.pl')
-rwxr-xr-xPorting/add-package.pl8
1 files changed, 4 insertions, 4 deletions
diff --git a/Porting/add-package.pl b/Porting/add-package.pl
index 948f16e1d9..88b96fc9df 100755
--- a/Porting/add-package.pl
+++ b/Porting/add-package.pl
@@ -94,7 +94,7 @@ my $ModName; # name of the module
my @ModFiles; # the .PMs in this package
{ print "Creating top level dir..." if $Verbose;
### make sure we get the shortest file, so we dont accidentally get
### a subdir
@ModFiles = sort { length($a) <=> length($b) }
map { chomp; $_ }
@@ -344,7 +344,7 @@ my @ChangedFiles;
}
### we need some entries in a vms specific file as well..
### except, i dont understand how it works or what it does, and it
### looks all a bit odd... so lets just print a warning...
### the entries look something like this:
# ./vms/descrip_mms.template:utils4 = [.utils]enc2xs.com
@@ -358,8 +358,8 @@ my @ChangedFiles;
print $/.$/;
print " WARNING! You should add entries like the following\n"
. " to $file (Using $TestBin as an example)\n"
- . " Unfortunately I dont understand what these entries\n"
- . " do, so I wont change them automatically:\n\n";
+ . " Unfortunately I don't understand what these entries\n"
+ . " do, so I won't change them automatically:\n\n";
print `grep -nC1 $TestBin $Repo/$file`;
print $/.$/;
@@ -94,7 +94,7 @@ my $ModName; # name of the module
my @ModFiles; # the .PMs in this package
{ print "Creating top level dir..." if $Verbose;
- ### make sure we get the shortest file, so we dont accidentally get
+ ### make sure we get the shortest file, so we don't accidentally get
### a subdir
@@ -344,7 +344,7 @@ my @ChangedFiles;
}
### we need some entries in a vms specific file as well..
- ### except, i dont understand how it works or what it does, and it
+ ### except, I don't understand how it works or what it does, and it
### looks all a bit odd... so lets just print a warning...
### the entries look something like this: